@@ -2,6 +2,7 @@
 
 # Build static.
 cmake -D CMAKE_INSTALL_PREFIX=$PREFIX \
+      -D CMAKE_BUILD_TYPE=Release \
       -D CMAKE_INSTALL_LIBDIR:PATH=$PREFIX/lib \
       -D ENABLE_DAP=ON \
       -D ENABLE_HDF4=ON \
@@ -14,13 +15,14 @@ cmake -D CMAKE_INSTALL_PREFIX=$PREFIX \
       -D CURL_INCLUDE_DIR=$PREFIX/include \
       -D CURL_LIBRARY=$PREFIX/lib/libcurl${SHLIB_EXT} \
       $SRC_DIR
-make
+make -j$CPU_COUNT
 # ctest  # Run only for the shared lib build to save time.
-make install
+make install -j$CPU_COUNT
 make clean
 
 # Build shared.
 cmake -D CMAKE_INSTALL_PREFIX=$PREFIX \
+      -D CMAKE_BUILD_TYPE=Release \
       -D CMAKE_INSTALL_LIBDIR:PATH=$PREFIX/lib \
       -D ENABLE_DAP=ON \
       -D ENABLE_HDF4=ON \
@@ -33,6 +35,6 @@ cmake -D CMAKE_INSTALL_PREFIX=$PREFIX \
       -D CURL_INCLUDE_DIR=$PREFIX/include \
       -D CURL_LIBRARY=$PREFIX/lib/libcurl${SHLIB_EXT} \
       $SRC_DIR
-make
+make -j$CPU_COUNT
 ctest
-make install
+make install -j$CPU_COUNT
